==> fl_drag_picture-0.0.3.tar.gz: lib/fl_drag_picture.dart <==
import 'package:fl_drag_picture/drag_picture_logic.dart';
import 'package:fl_drag_picture/photo_show_gallery.dart';
import 'package:flutter_draggable_gridview/flutter_draggable_gridview.dart';
import 'package:get/get.dart';
import 'package:image_cropper/image_cropper.dart';
import 'package:open_app_settings/open_app_settings.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:photo_view/photo_view.dart';
import 'package:photo_view/photo_view_gallery.dart';

import 'base_dialog.dart';
import 'fl_drag_picture_platform_interface.dart';

import 'dart:io';

import 'package:flutter/material.dart';

class FlDragPicture extends StatefulWidget {
  final int maxSelect;
  final List<String>? picList;
  final Function? onTapPic;
  final Function? uploadPic;
  final Function? lookBigPic;
  final Function? openPic;
  bool? isShowBigPic;
  bool? isCanDrag;

  FlDragPicture(
      {Key? key,
      this.maxSelect = 6,
      this.picList,
      this.onTapPic,
      this.uploadPic,
      this.lookBigPic,
      this.isCanDrag,
      this.isShowBigPic,
      this.openPic})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _FlDragPictureState();
  }
}

class _FlDragPictureState extends State<FlDragPicture>
    with WidgetsBindingObserver {
  ///当前是否正在选择图片
  final bool _isSelect = false;
  var selectedBottomImageList1 = <File>[];
  var dragList = <int>[];
  final logic = Get.put(DragPictureController());

  @override
  void initState() {
    super.initState();
    for (int i = 0; i < widget.picList!.length; i++) {
      if (i == 0) {
        logic.firstPicImage.value = widget.picList![i];
      } else {
        logic.otherPicImage.value.add(widget.picList![i]);
      }
      logic.showImageList.add(SelectImg(i.toString(), widget.picList![i]));
    }
    _generateImageData();
    Future.delayed(Duration(milliseconds: 600), () {
      _generateImageData();
      setState(() {});
    });
    //绑定视图监听
    WidgetsBinding.instance!.addObserver(this);
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    switch (state) {
      case AppLifecycleState.inactive:
        // 处于这种状态的应用程序应该假设它们可能在任何时候暂停。
        break;
      case AppLifecycleState.resumed:
        //从后台切换前台，界面可见
        break;
      case AppLifecycleState.paused:
        // 界面不可见，后台
        break;
      case AppLifecycleState.detached:
        // APP结束时调用
        break;
    }
  }

  @override
  void dispose() {
    //解绑视图监听
    WidgetsBinding.instance.removeObserver(this);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    _generateImageData();
    //圆角矩形剪裁
    return ClipRRect(
      //圆角
      borderRadius: const BorderRadius.all(Radius.circular(16)),
      child: Container(
        // color: Color(0xffFFFFFF),
        //宽度填充
        width: double.infinity,
        //统一内边距
        padding: const EdgeInsets.all(15),
        //垂直方向的线性排列
        child: Column(
          //水平方向
          crossAxisAlignment: CrossAxisAlignment.start,
          //包裹
          mainAxisSize: MainAxisSize.min,
          children: [
            //显示的图片
            buildGridView(),
          ],
        ),
      ),
    );
  }

  buildGridView() {
    return Obx(() => SizedBox(
        height: logic.showImageList.length >= 3 ? 225 : 115,
        child: DraggableGridViewBuilder(
            gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
                //横轴元素个数
                crossAxisCount: 3,
                //主轴间距
                mainAxisSpacing: 1.0,
                //从轴间距
                crossAxisSpacing: 5.0,
                //子组件宽高长度比例
                childAspectRatio: 1.0),
            children: logic.listOfDraggableGridItem,
            isOnlyLongPress: false,
            dragCompletion: (List<DraggableGridItem> list, int beforeIndex,
                int afterIndex) {
              dragList = [];
              for (var element in list) {
                if (element.child.key.toString().contains("[<") ||
                    element.child.key.toString().contains(">]")) {
                  var temp = element.child.key.toString();
                  List x = temp.split("");
                  String str = '';
                  for (var element in x) {
                    if (element == "0" ||
                        element == "1" ||
                        element == "2" ||
                        element == "3" ||
                        element == "4" ||
                        element == "5" ||
                        element == "6" ||
                        element == "7" ||
                        element == "8" ||
                        element == "9") {
                      str += element;
                    }
                  }
                  if (str != "") {
                    dragList.add(int.parse(str.toString()));
                  }
                }
              }
              print("----------------343242");
              print(dragList);
              print('onDragAccept: $beforeIndex -> $afterIndex');
            },
            dragFeedback: (List<DraggableGridItem> list, int index) {
              return SizedBox(
                width: 120,
                height: 120,
                child: list[index].child,
              );
            },
            dragPlaceHolder: (List<DraggableGridItem> list, int index) {
              return PlaceHolderWidget(
                child: Container(
                  color: Colors.transparent,
                ),
              );
            })));
  }

  void _generateImageData() {
    logic.listOfDraggableGridItem = [];
    for (int i = 0; i < logic.showImageList.length; i++) {
      logic.listOfDraggableGridItem.add(
        DraggableGridItem(
            child: generateImage(i), isDraggable: i == 0 ? false : true),
      );
    }
    if (logic.showImageList.length < 6) {
      logic.listOfDraggableGridItem.add(
        DraggableGridItem(child: add(), isDraggable: false),
      );
      logic.update([6]);
      logic.showImageList.refresh();
    }
  }

  Widget add() {
    return _isSelect
        ? const Center(child: Text("..."))
        : GestureDetector(
            onTap: () async {
              if (await Permission.camera.isGranted) {
                FocusScope.of(context).requestFocus(FocusNode());
                widget.openPic?.call();
              } else {
                _showRequestCameraPermissionDialog(() {
                  FocusScope.of(context).requestFocus(FocusNode());
                  widget.openPic?.call();
                });
              }
            },
            child: Container(
                decoration: BoxDecoration(
                  color: const Color(0xFF292B3C),
                  borderRadius: BorderRadius.circular(10), // 也可控件一边圆角大小
                ),
                alignment: Alignment.center,
                margin: const EdgeInsets.only(top: 10),
                child: Image.asset("assets/images/common/mine_edit_add.png",
                    width: 24, height: 24)),
          );
  }

  Widget generateImage(int index) {
    //显示当前的图片
    String entity = logic.showImageList[index].photo!;
    return Container(
      key: Key(logic.showImageList[index].id.toString()),
      color: Colors.transparent,
      //层叠布局
      child: Stack(
        alignment: Alignment.topRight,
        children: [
          Positioned.fill(
            top: 10,
            child: GestureDetector(
              onTap: () async {
                widget.openPic?.call();
                if (widget.isShowBigPic == true) {
                  if (index == 0) {
                    Navigator.of(context).push(FadeRoute(
                        page: PhotoViewGalleryScreen(
                      images: [logic.firstPicImage.value], //传入图片list
                      index: index, //传入当前点击的图片的index
                      heroTag: "simple", //传入当前点击的图片的hero tag （可选）
                    )));
                  } else {
                    //FadeRoute是自定义的切换过度动画（渐隐渐现） 如果不需要 可以使用默认的MaterialPageRoute
                    Navigator.of(context).push(FadeRoute(
                        page: PhotoViewGalleryScreen(
                      images: logic.otherPicImage.value, //传入图片list
                      index: index - 1, //传入当前点击的图片的index
                      heroTag: logic.otherPicImage[index - 1]
                          .toString(), //传入当前点击的图片的hero tag （可选）
                    )));
                  }
                }
              },
              child: Container(
                width: 109,
                height: 109,
                padding: const EdgeInsets.all(1),
                color: Colors.transparent,
                child: buildImageWidget(entity),
              ),
            ),
          ),
          index == 0
              ? Container()
              : Positioned(
                  top: 14,
                  right: 4,
                  child: GestureDetector(
                      onTap: () {
                        FocusScope.of(context).requestFocus(FocusNode());
                        onDeleteImageFunction(index);
                      },
                      child: Image.asset(
                          "assets/images/common/icon_pic_delete.png",
                          width: 22,
                          height: 22)),
                ),
          index == 0
              ? Positioned(
                  left: 0,
                  bottom: 0,
                  child: Container(
                    decoration: BoxDecoration(
                        color: const Color(0xFF000000).withOpacity(0.4),
                        borderRadius: const BorderRadius.only(
                            bottomLeft: Radius.circular(20),
                            bottomRight: Radius.circular(20))),
                    alignment: Alignment.center,
                    width: 112,
                    height: 22,
                    child: const Text("头像",
                        style: TextStyle(fontSize: 14, color: Colors.white)),
                  ))
              : Container(),
        ],
      ),
    );
  }

  PhotoViewGalleryPageOptions _buildItem(BuildContext context, int index) {
    final String item = widget.picList![index];
    return PhotoViewGalleryPageOptions(
      // 图片加载器 支持本地、网络
      imageProvider: NetworkImage(item ?? ""),
      // 初始化大小 全部展示
      initialScale: PhotoViewComputedScale.contained,
      // 最小展示 缩放最小值
      minScale: PhotoViewComputedScale.contained * 0.5,
      // 最大展示 缩放最大值
      maxScale: PhotoViewComputedScale.covered * 4,
      // hero动画设置
      heroAttributes: PhotoViewHeroAttributes(tag: item ?? ""),
    );
  }

  Widget buildImageWidget(entity) {
    return RepaintBoundary(
      child: ClipRRect(
        borderRadius: BorderRadius.circular(16.0),
        child: Image.network(
          entity!,
          fit: BoxFit.cover,
        ),
      ),
    );
  }

  ///最大选择图片数据限制
  getSelectCount() {
    if (logic.showImageList.length >= widget.maxSelect) {
      return widget.maxSelect;
    }
    return logic.showImageList.length + 1;
  }

  Future<File?> _cropImage(
      File imageFile, int imageWidth, int imageHeight) async {
    double cropWidth = imageWidth > imageHeight
        ? imageHeight.toDouble()
        : imageWidth.toDouble();
    if (cropWidth == 0) {
      cropWidth = MediaQuery.of(context).size.width;
    }

    return await ImageCropper().cropImage(
        sourcePath: imageFile.path,
        aspectRatioPresets: [
          CropAspectRatioPreset.square,
        ],
        androidUiSettings: const AndroidUiSettings(
            hideBottomControls: true,
            toolbarTitle: '剪切',
            toolbarColor: Colors.white,
            toolbarWidgetColor: Color(0xff222222),
            initAspectRatio: CropAspectRatioPreset.original,
            lockAspectRatio: true),
        iosUiSettings: IOSUiSettings(
          rectX: (imageWidth - cropWidth) / 2.0,
          rectY: (imageHeight - cropWidth) / 2.0,
          rectWidth: cropWidth,
          rectHeight: cropWidth,
          resetButtonHidden: true,
          minimumAspectRatio: 1.0,
          aspectRatioLockEnabled: true,
          hidesNavigationBar: true,
        ));
  }

  /// 弹出申请相机权限的弹窗
  void _showRequestCameraPermissionDialog(Function() function) async {
    var status = await Permission.camera.status;
    if (status.isDenied) {
      Map<Permission, PermissionStatus> statuses =
          await [Permission.camera].request();
      if (statuses[Permission.camera] == PermissionStatus.granted) {
        function();
      } else {
        _showOpenSettingDialog("相机");
      }
    } else if (status.isPermanentlyDenied) {
      _showPermanentlyDeniedDialog("相机");
    } else {
      function();
    }
  }

  ///删除照片
  void onDeleteImageFunction(int index) {
    logic.showImageList.value.removeAt(index);
    logic.otherPicImage.value.removeAt(index - 1);
    logic.listOfDraggableGridItem.removeAt(index);
    _generateImageData();
  }

  _showOpenSettingDialog(String permissionName) {
    DialogUtils.show(context,
        widget: BaseDialog(
          title: "提示",
          onPressed: () {
            Navigator.of(context).pop();
            OpenAppSettings.openAppSettings();
          },
          subTitle: "$permissionName权限未打开，是否去设置？",
          confirmText: "设置",
        ));
  }

  _showPermanentlyDeniedDialog(String permissionName) {
    DialogUtils.show(context,
        widget: BaseDialog(
          title: "提示",
          onPressed: () {
            Navigator.of(context).pop();
            OpenAppSettings.openAppSettings();
          },
          subTitle: "已禁止访问$permissionName权限，是否去修改设置？",
          confirmText: "设置",
        ));
  }
}

==> fl_drag_picture-0.0.5.tar.gz: lib/fl_drag_picture.dart <==
import 'package:fl_drag_picture/drag_picture_logic.dart';
import 'package:fl_drag_picture/photo_show_gallery.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter_draggable_gridview/flutter_draggable_gridview.dart';
import 'package:get/get.dart';
import 'package:image_cropper/image_cropper.dart';
import 'package:open_app_settings/open_app_settings.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:photo_view/photo_view.dart';
import 'package:photo_view/photo_view_gallery.dart';
import 'base_dialog.dart';
import 'dart:io';
import 'package:flutter/material.dart';

class FlDragPicture extends StatefulWidget {
  final int maxSelect;
  final List<String>? picList;
  final Function? onTapPic;
  final Function? uploadPic;
  final Function? lookBigPic;
  final Function? openPic;
  bool? isShowBigPic;
  bool? isCanDrag;
  bool? isNeedCrop;
  bool? isNeedCompress;

  FlDragPicture(
      {Key? key,
      this.maxSelect = 6,
      this.picList,
      this.onTapPic,
      this.uploadPic,
      this.lookBigPic,
      this.isCanDrag,
      this.isShowBigPic,
      this.openPic,
      this.isNeedCrop,
      this.isNeedCompress})
      : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return _FlDragPictureState();
  }
}

class _FlDragPictureState extends State<FlDragPicture>
    with WidgetsBindingObserver {
  ///当前是否正在选择图片
  final bool _isSelect = false;
  var selectedBottomImageList1 = <File>[];
  var dragList = <int>[];
  final logic = Get.put(DragPictureController());

  @override
  void initState() {
    super.initState();
    for (int i = 0; i < widget.picList!.length; i++) {
      if (i == 0) {
        logic.firstPicImage.value = widget.picList![i];
      } else {
        logic.otherPicImage.value.add(widget.picList![i]);
      }
      logic.showImageList.add(SelectImg(i.toString(), widget.picList![i]));
    }
    _generateImageData();
    Future.delayed(const Duration(milliseconds: 600), () {
      _generateImageData();
      setState(() {});
    });
    //绑定视图监听
    WidgetsBinding.instance!.addObserver(this);
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    switch (state) {
      case AppLifecycleState.inactive:
        // 处于这种状态的应用程序应该假设它们可能在任何时候暂停。
        break;
      case AppLifecycleState.resumed:
        //从后台切换前台，界面可见
        break;
      case AppLifecycleState.paused:
        // 界面不可见，后台
        break;
      case AppLifecycleState.detached:
        // APP结束时调用
        break;
    }
  }

  @override
  void dispose() {
    //解绑视图监听
    WidgetsBinding.instance.removeObserver(this);
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    _generateImageData();
    //圆角矩形剪裁
    return ClipRRect(
      //圆角
      borderRadius: const BorderRadius.all(Radius.circular(16)),
      child: Container(
        // color: Color(0xffFFFFFF),
        //宽度填充
        width: double.infinity,
        //统一内边距
        padding: const EdgeInsets.all(15),
        //垂直方向的线性排列
        child: Column(
          //水平方向
          crossAxisAlignment: CrossAxisAlignment.start,
          //包裹
          mainAxisSize: MainAxisSize.min,
          children: [
            //显示的图片
            buildGridView(),
          ],
        ),
      ),
    );
  }

  buildGridView() {
    return Obx(() => SizedBox(
        height: logic.showImageList.length >= 3 ? 225 : 115,
        child: DraggableGridViewBuilder(
            gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
                //横轴元素个数
                crossAxisCount: 3,
                //主轴间距
                mainAxisSpacing: 1.0,
                //从轴间距
                crossAxisSpacing: 5.0,
                //子组件宽高长度比例
                childAspectRatio: 1.0),
            children: logic.listOfDraggableGridItem,
            isOnlyLongPress: false,
            dragCompletion: (List<DraggableGridItem> list, int beforeIndex,
                int afterIndex) {
              dragList = [];
              for (var element in list) {
                if (element.child.key.toString().contains("[<") ||
                    element.child.key.toString().contains(">]")) {
                  var temp = element.child.key.toString();
                  List x = temp.split("");
                  String str = '';
                  for (var element in x) {
                    if (element == "0" ||
                        element == "1" ||
                        element == "2" ||
                        element == "3" ||
                        element == "4" ||
                        element == "5" ||
                        element == "6" ||
                        element == "7" ||
                        element == "8" ||
                        element == "9") {
                      str += element;
                    }
                  }
                  if (str != "") {
                    dragList.add(int.parse(str.toString()));
                  }
                }
              }
              if (kDebugMode) {
                print('onDragAccept: $beforeIndex -> $afterIndex');
              }
            },
            dragFeedback: (List<DraggableGridItem> list, int index) {
              return SizedBox(
                width: 120,
                height: 120,
                child: list[index].child,
              );
            },
            dragPlaceHolder: (List<DraggableGridItem> list, int index) {
              return PlaceHolderWidget(
                child: Container(
                  color: Colors.transparent,
                ),
              );
            })));
  }

  void _generateImageData() {
    logic.listOfDraggableGridItem = [];
    for (int i = 0; i < logic.showImageList.length; i++) {
      logic.listOfDraggableGridItem.add(
        DraggableGridItem(
            child: generateImage(i), isDraggable: i == 0 ? false : true),
      );
    }
    if (logic.showImageList.length < 6) {
      logic.listOfDraggableGridItem.add(
        DraggableGridItem(child: add(), isDraggable: false),
      );
      logic.update([6]);
      logic.showImageList.refresh();
    }
  }

  Widget add() {
    return _isSelect
        ? const Center(child: Text("..."))
        : GestureDetector(
            onTap: () async {
              if (await Permission.camera.isGranted) {
                FocusScope.of(context).requestFocus(FocusNode());
                widget.openPic?.call();
              } else {
                _showRequestCameraPermissionDialog(() {
                  FocusScope.of(context).requestFocus(FocusNode());
                  widget.openPic?.call();
                });
              }
            },
            child: Container(
                decoration: BoxDecoration(
                  color: const Color(0xFF292B3C),
                  borderRadius: BorderRadius.circular(10), // 也可控件一边圆角大小
                ),
                alignment: Alignment.center,
                margin: const EdgeInsets.only(top: 10),
                child: Image.asset("assets/images/common/mine_edit_add.png",
                    width: 24, height: 24)),
          );
  }

  Widget generateImage(int index) {
    //显示当前的图片
    String entity = logic.showImageList[index].photo!;
    return Container(
      key: Key(logic.showImageList[index].id.toString()),
      color: Colors.transparent,
      //层叠布局
      child: Stack(
        alignment: Alignment.topRight,
        children: [
          Positioned.fill(
            top: 10,
            child: GestureDetector(
              onTap: () async {
                widget.openPic?.call();
                if (widget.isShowBigPic == true) {
                  if (index == 0) {
                    Navigator.of(context).push(FadeRoute(
                        page: PhotoViewGalleryScreen(
                      images: [logic.firstPicImage.value], //传入图片list
                      index: index, //传入当前点击的图片的index
                      heroTag: "simple", //传入当前点击的图片的hero tag （可选）
                    )));
                  } else {
                    //FadeRoute是自定义的切换过度动画（渐隐渐现） 如果不需要 可以使用默认的MaterialPageRoute
                    Navigator.of(context).push(FadeRoute(
                        page: PhotoViewGalleryScreen(
                      images: logic.otherPicImage.value, //传入图片list
                      index: index - 1, //传入当前点击的图片的index
                      heroTag: logic.otherPicImage[index - 1]
                          .toString(), //传入当前点击的图片的hero tag （可选）
                    )));
                  }
                }
              },
              child: Container(
                width: 109,
                height: 109,
                padding: const EdgeInsets.all(1),
                color: Colors.transparent,
                child: buildImageWidget(entity),
              ),
            ),
          ),
          index == 0
              ? Container()
              : Positioned(
                  top: 14,
                  right: 4,
                  child: GestureDetector(
                      onTap: () {
                        FocusScope.of(context).requestFocus(FocusNode());
                        onDeleteImageFunction(index);
                      },
                      child: Image.asset(
                          "assets/images/common/icon_pic_delete.png",
                          width: 22,
                          height: 22)),
                ),
          index == 0
              ? Positioned(
                  left: 0,
                  bottom: 0,
                  child: Container(
                    decoration: BoxDecoration(
                        color: const Color(0xFF000000).withOpacity(0.4),
                        borderRadius: const BorderRadius.only(
                            bottomLeft: Radius.circular(20),
                            bottomRight: Radius.circular(20))),
                    alignment: Alignment.center,
                    width: 112,
                    height: 22,
                    child: const Text("头像",
                        style: TextStyle(fontSize: 14, color: Colors.white)),
                  ))
              : Container(),
        ],
      ),
    );
  }

  PhotoViewGalleryPageOptions _buildItem(BuildContext context, int index) {
    final String item = widget.picList![index];
    return PhotoViewGalleryPageOptions(
      // 图片加载器 支持本地、网络
      imageProvider: NetworkImage(item),
      // 初始化大小 全部展示
      initialScale: PhotoViewComputedScale.contained,
      // 最小展示 缩放最小值
      minScale: PhotoViewComputedScale.contained * 0.5,
      // 最大展示 缩放最大值
      maxScale: PhotoViewComputedScale.covered * 4,
      // hero动画设置
      heroAttributes: PhotoViewHeroAttributes(tag: item),
    );
  }

  Widget buildImageWidget(entity) {
    return RepaintBoundary(
      child: ClipRRect(
        borderRadius: BorderRadius.circular(16.0),
        child: Image.network(
          entity!,
          fit: BoxFit.cover,
        ),
      ),
    );
  }

  ///最大选择图片数据限制
  getSelectCount() {
    if (logic.showImageList.length >= widget.maxSelect) {
      return widget.maxSelect;
    }
    return logic.showImageList.length + 1;
  }

  Future<File?> _cropImage(
      File imageFile, int imageWidth, int imageHeight) async {
    double cropWidth = imageWidth > imageHeight
        ? imageHeight.toDouble()
        : imageWidth.toDouble();
    if (cropWidth == 0) {
      cropWidth = MediaQuery.of(context).size.width;
    }

    return await ImageCropper().cropImage(
        sourcePath: imageFile.path,
        aspectRatioPresets: [
          CropAspectRatioPreset.square,
        ],
        androidUiSettings: const AndroidUiSettings(
            hideBottomControls: true,
            toolbarTitle: '剪切',
            toolbarColor: Colors.white,
            toolbarWidgetColor: Color(0xff222222),
            initAspectRatio: CropAspectRatioPreset.original,
            lockAspectRatio: true),
        iosUiSettings: IOSUiSettings(
          rectX: (imageWidth - cropWidth) / 2.0,
          rectY: (imageHeight - cropWidth) / 2.0,
          rectWidth: cropWidth,
          rectHeight: cropWidth,
          resetButtonHidden: true,
          minimumAspectRatio: 1.0,
          aspectRatioLockEnabled: true,
          hidesNavigationBar: true,
        ));
  }

  /// 弹出申请相机权限的弹窗
  void _showRequestCameraPermissionDialog(Function() function) async {
    var status = await Permission.camera.status;
    if (status.isDenied) {
      Map<Permission, PermissionStatus> statuses =
          await [Permission.camera].request();
      if (statuses[Permission.camera] == PermissionStatus.granted) {
        function();
      } else {
        _showOpenSettingDialog("相机");
      }
    } else if (status.isPermanentlyDenied) {
      _showPermanentlyDeniedDialog("相机");
    } else {
      function();
    }
  }

  ///删除照片
  void onDeleteImageFunction(int index) {
    logic.showImageList.value.removeAt(index);
    logic.otherPicImage.value.removeAt(index - 1);
    logic.listOfDraggableGridItem.removeAt(index);
    _generateImageData();
  }

  _showOpenSettingDialog(String permissionName) {
    DialogUtils.show(context,
        widget: BaseDialog(
          title: "提示",
          onPressed: () {
            Navigator.of(context).pop();
            OpenAppSettings.openAppSettings();
          },
          subTitle: "$permissionName权限未打开，是否去设置？",
          confirmText: "设置",
        ));
  }

  _showPermanentlyDeniedDialog(String permissionName) {
    DialogUtils.show(context,
        widget: BaseDialog(
          title: "提示",
          onPressed: () {
            Navigator.of(context).pop();
            OpenAppSettings.openAppSettings();
          },
          subTitle: "已禁止访问$permissionName权限，是否去修改设置？",
          confirmText: "设置",
        ));
  }
}
